@@ -59,7 +59,7 @@ add_function_parentheses = True
 add_module_names = True
 
 # The name of the Pygments (syntax highlighting) style to use.
-pygments_style = 'sphinx'
+pygments_style = 'native'
 
 # -- Options for HTML output --------------------------------------------------
 
@@ -69,6 +69,10 @@ pygments_style = 'sphinx'
 html_theme = 'openstackdocs'
 # html_static_path = ['static']
 
+html_theme_options = {
+    "show_other_versions": True,
+}
+
 # Output file base name for HTML help builder.
 htmlhelp_basename = '%sdoc' % project
 
@@ -101,14 +105,11 @@ openstack_projects = [
     'keystone',
     'kolla',
     'kolla-ansible',
-    'magnum',
     'manila',
     'networking-sfc',
     'neutron-vpnaas',
     'neutron',
     'nova',
-    'octavia',
     'oslotest',
     'swift',
-    'watcher',
 ]
