@@ -23,7 +23,10 @@ function setup_openstack_clients {
     if [[ $SCENARIO == scenario_nfv ]]; then
         packages+=(python-tackerclient python-barbicanclient python-mistralclient)
     fi
-    virtualenv ~/openstackclient-venv
+    if [[ "debian" == $BASE_DISTRO ]]; then
+        sudo apt -y install python3-venv
+    fi
+    python3 -m venv ~/openstackclient-venv
     ~/openstackclient-venv/bin/pip install -U pip
     ~/openstackclient-venv/bin/pip install -c $UPPER_CONSTRAINTS ${packages[@]}
 }
@@ -39,13 +42,13 @@ function prepare_images {
         GATE_IMAGES="bifrost"
     fi
 
-    if [[ $SCENARIO == "ceph" ]]; then
-        GATE_IMAGES+=",^ceph,^cinder"
+    if [[ $SCENARIO == "ceph-ansible" ]]; then
+        GATE_IMAGES+=",^cinder"
     fi
 
     if [[ $SCENARIO == "zun" ]]; then
         GATE_IMAGES+=",^zun,^kuryr,^etcd,^cinder,^iscsid"
-        if [[ $BASE_DISTRO != "centos" ]] || [[ $BASE_DISTRO_MAJOR_VERSION -eq 7 ]]; then
+        if [[ $BASE_DISTRO != "centos" ]]; then
             GATE_IMAGES+=",^tgtd"
         fi
     fi
@@ -64,12 +67,12 @@ function prepare_images {
         GATE_IMAGES+=",^swift"
     fi
 
-    if [[ $SCENARIO == "mariadb" ]]; then
-        GATE_IMAGES="^cron,^haproxy,^keepalived,^kolla-toolbox,^mariadb"
+    if [[ $SCENARIO == "ovn" ]]; then
+        GATE_IMAGES+=",^ovn"
     fi
 
-    if [[ $SCENARIO == "prometheus-efk" ]]; then
-        GATE_IMAGES="^cron,^elasticsearch,^fluentd,^grafana,^haproxy,^keepalived,^kibana,^kolla-toolbox,^mariadb,^memcached,^prometheus,^rabbitmq"
+    if [[ $SCENARIO == "mariadb" ]]; then
+        GATE_IMAGES="^cron,^fluentd,^haproxy,^keepalived,^kolla-toolbox,^mariadb"
     fi
 
     # NOTE(yoctozepto): we cannot build and push at the same time on debian
@@ -90,17 +93,10 @@ registry = 127.0.0.1:4000
 push = ${PUSH}
 logs_dir = /tmp/logs/build
 template_override = /etc/kolla/template_overrides.j2
-EOF
+# NOTE(yoctozepto): to avoid issues with IPv6 not enabled in the docker daemon
+# and since we don't need isolated networks here, use host networking
+network_mode = host
 
-    # TODO(mgoddard): Remove this if block when CentOS 7 is no longer
-    # supported.
-    if [[ $BASE_DISTRO == "centos" ]] && [[ $BASE_DISTRO_MAJOR_VERSION -eq 8 ]]; then
-        sudo tee -a /etc/kolla/kolla-build.conf <<EOF
-base_tag = 8
-EOF
-    fi
-
-    sudo tee -a /etc/kolla/kolla-build.conf <<EOF
 [profiles]
 gate = ${GATE_IMAGES}
 EOF
@@ -109,10 +105,10 @@ EOF
 
     sudo docker run -d -p 4000:5000 --restart=always -v /opt/kolla_registry/:/var/lib/registry --name registry registry:2
 
-    virtualenv ~/kolla-venv
+    python3 -m venv ~/kolla-venv
     . ~/kolla-venv/bin/activate
 
-    pip install -c $UPPER_CONSTRAINTS "${KOLLA_SRC_DIR}"
+    pip install "${KOLLA_SRC_DIR}"
 
     sudo ~/kolla-venv/bin/kolla-build
 
